aboutsummaryrefslogtreecommitdiffstats
path: root/tap-rpcprogs.c
diff options
context:
space:
mode:
authorsahlberg <sahlberg@f5534014-38df-0310-8fa8-9805f1628bb7>2004-05-17 20:06:32 +0000
committersahlberg <sahlberg@f5534014-38df-0310-8fa8-9805f1628bb7>2004-05-17 20:06:32 +0000
commitd15d3fb9c074118f385415b1ad9e88d40b58530c (patch)
treeb6d59db9a4b5906197670897e519bfc3e7dedb4a /tap-rpcprogs.c
parent9142e524816f39c20374d8331f4ad54bf94aaed7 (diff)
In rpc programs statistics, change RTT (RoundTripTime) to SRT
(ServiceResponseTime) since that is a more appropriate name for these stats. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@10913 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'tap-rpcprogs.c')
-rw-r--r--tap-rpcprogs.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tap-rpcprogs.c b/tap-rpcprogs.c
index 7b6155a6fc..51454e8582 100644
--- a/tap-rpcprogs.c
+++ b/tap-rpcprogs.c
@@ -1,7 +1,7 @@
/* tap-rpcprogs.c
* rpcstat 2002 Ronnie Sahlberg
*
- * $Id: tap-rpcprogs.c,v 1.5 2003/04/23 08:20:02 guy Exp $
+ * $Id: tap-rpcprogs.c,v 1.6 2004/05/17 20:06:32 sahlberg Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides rpc call/reply RTT statistics to tethereal.
* It is only used by tethereal and not ethereal
*/
@@ -193,7 +193,7 @@ rpcprogs_draw(void *dummy _U_)
printf("\n");
printf("===================================================================\n");
printf("ONC-RPC Program Statistics:\n");
- printf("Program Version Calls Min RTT Max RTT Avg RTT\n");
+ printf("Program Version Calls Min SRT Max SRT Avg SRT\n");
for(rp=prog_list;rp;rp=rp->next){
/* scale it to units of 10us.*/
/* for long captures with a large tot time, this can overflow on 32bit */
@@ -22,7 +22,7 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides rpc call/reply RTT statistics to tethereal.
+/* This module provides rpc call/reply SRT statistics to tethereal.
* It is only used by tethereal and not ethereal
*/